import { Metric, MetricOptions } from "../../../aws-cloudwatch";
import { IResource } from "../../../core";
import { IDomainName } from './domain-name';
/**
 * (experimental) Represents a Stage.
 *
 * @experimental
 */
export interface IStage extends IResource {
    /**
     * (experimental) The name of the stage;
     *
     * its primary identifier.
     *
     * @experimental
     * @attribute true
     */
    readonly stageName: string;
    /**
     * (experimental) The URL to this stage.
     *
     * @experimental
     */
    readonly url: string;
    /**
     * (experimental) Return the given named metric for this HTTP Api Gateway Stage.
     *
     * @default - average over 5 minutes
     * @experimental
     */
    metric(metricName: string, props?: MetricOptions): Metric;
    /**
     * (experimental) Metric for the number of client-side errors captured in a given period.
     *
     * @default - sum over 5 minutes
     * @experimental
     */
    metricClientError(props?: MetricOptions): Metric;
    /**
     * (experimental) Metric for the number of server-side errors captured in a given period.
     *
     * @default - sum over 5 minutes
     * @experimental
     */
    metricServerError(props?: MetricOptions): Metric;
    /**
     * (experimental) Metric for the amount of data processed in bytes.
     *
     * @default - sum over 5 minutes
     * @experimental
     */
    metricDataProcessed(props?: MetricOptions): Metric;
    /**
     * (experimental) Metric for the total number API requests in a given period.
     *
     * @default - SampleCount over 5 minutes
     * @experimental
     */
    metricCount(props?: MetricOptions): Metric;
    /**
     * (experimental) Metric for the time between when API Gateway relays a request to the backend and when it receives a response from the backend.
     *
     * @default - no statistic
     * @experimental
     */
    metricIntegrationLatency(props?: MetricOptions): Metric;
    /**
     * (experimental) The time between when API Gateway receives a request from a client and when it returns a response to the client.
     *
     * The latency includes the integration latency and other API Gateway overhead.
     *
     * @default - no statistic
     * @experimental
     */
    metricLatency(props?: MetricOptions): Metric;
}
/**
 * (experimental) Options for DomainMapping.
 *
 * @experimental
 */
export interface DomainMappingOptions {
    /**
     * (experimental) The domain name for the mapping.
     *
     * @experimental
     */
    readonly domainName: IDomainName;
    /**
     * (experimental) The API mapping key.
     *
     * Leave it undefined for the root path mapping.
     *
     * @default - empty key for the root path mapping
     * @experimental
     */
    readonly mappingKey?: string;
}
/**
 * (experimental) Options required to create a new stage.
 *
 * Options that are common between HTTP and Websocket APIs.
 *
 * @experimental
 */
export interface StageOptions {
    /**
     * (experimental) Whether updates to an API automatically trigger a new deployment.
     *
     * @default false
     * @experimental
     */
    readonly autoDeploy?: boolean;
    /**
     * (experimental) The options for custom domain and api mapping.
     *
     * @default - no custom domain and api mapping configuration
     * @experimental
     */
    readonly domainMapping?: DomainMappingOptions;
}
/**
 * (experimental) The attributes used to import existing Stage.
 *
 * @experimental
 */
export interface StageAttributes {
    /**
     * (experimental) The name of the stage.
     *
     * @experimental
     */
    readonly stageName: string;
}
