import * as codebuild from "../../aws-codebuild";
import * as events from "../../aws-events";
import * as iam from "../../aws-iam";
import * as sqs from "../../aws-sqs";
/**
 * (experimental) Customize the CodeBuild Event Target.
 *
 * @experimental
 */
export interface CodeBuildProjectProps {
    /**
     * (experimental) The role to assume before invoking the target (i.e., the codebuild) when the given rule is triggered.
     *
     * @default - a new role will be created
     * @experimental
     */
    readonly eventRole?: iam.IRole;
    /**
     * (experimental) The event to send to CodeBuild.
     *
     * This will be the payload for the StartBuild API.
     *
     * @default - the entire EventBridge event
     * @experimental
     */
    readonly event?: events.RuleTargetInput;
    /**
     * (experimental) The SQS queue to be used as deadLetterQueue. Check out the [considerations for using a dead-letter queue](https://docs.aws.amazon.com/eventbridge/latest/userguide/rule-dlq.html#dlq-considerations).
     *
     * The events not successfully delivered are automatically retried for a specified period of time,
     * depending on the retry policy of the target.
     * If an event is not delivered before all retry attempts are exhausted, it will be sent to the dead letter queue.
     *
     * @default - no dead-letter queue
     * @experimental
     */
    readonly deadLetterQueue?: sqs.IQueue;
}
/**
 * (experimental) Start a CodeBuild build when an Amazon EventBridge rule is triggered.
 *
 * @experimental
 */
export declare class CodeBuildProject implements events.IRuleTarget {
    private readonly project;
    private readonly props;
    /**
     * @experimental
     */
    constructor(project: codebuild.IProject, props?: CodeBuildProjectProps);
    /**
     * (experimental) Allows using build projects as event rule targets.
     *
     * @experimental
     */
    bind(_rule: events.IRule, _id?: string): events.RuleTargetConfig;
}
