import * as events from "../../aws-events";
import * as lambda from "../../aws-lambda";
import * as sqs from "../../aws-sqs";
/**
 * (experimental) Customize the Lambda Event Target.
 *
 * @experimental
 */
export interface LambdaFunctionProps {
    /**
     * (experimental) The event to send to the Lambda.
     *
     * This will be the payload sent to the Lambda Function.
     *
     * @default the entire EventBridge event
     * @experimental
     */
    readonly event?: events.RuleTargetInput;
    /**
     * (experimental) The SQS queue to be used as deadLetterQueue. Check out the [considerations for using a dead-letter queue](https://docs.aws.amazon.com/eventbridge/latest/userguide/rule-dlq.html#dlq-considerations).
     *
     * The events not successfully delivered are automatically retried for a specified period of time,
     * depending on the retry policy of the target.
     * If an event is not delivered before all retry attempts are exhausted, it will be sent to the dead letter queue.
     *
     * @default - no dead-letter queue
     * @experimental
     */
    readonly deadLetterQueue?: sqs.IQueue;
}
/**
 * (experimental) Use an AWS Lambda function as an event rule target.
 *
 * @experimental
 */
export declare class LambdaFunction implements events.IRuleTarget {
    private readonly handler;
    private readonly props;
    /**
     * @experimental
     */
    constructor(handler: lambda.IFunction, props?: LambdaFunctionProps);
    /**
     * (experimental) Returns a RuleTarget that can be used to trigger this Lambda as a result from an EventBridge event.
     *
     * @experimental
     */
    bind(rule: events.IRule, _id?: string): events.RuleTargetConfig;
}
