import * as events from "../../aws-events";
import * as iam from "../../aws-iam";
import * as sqs from "../../aws-sqs";
import * as sfn from "../../aws-stepfunctions";
/**
 * (experimental) Customize the Step Functions State Machine target.
 *
 * @experimental
 */
export interface SfnStateMachineProps {
    /**
     * (experimental) The input to the state machine execution.
     *
     * @default the entire EventBridge event
     * @experimental
     */
    readonly input?: events.RuleTargetInput;
    /**
     * (experimental) The IAM role to be assumed to execute the State Machine.
     *
     * @default - a new role will be created
     * @experimental
     */
    readonly role?: iam.IRole;
    /**
     * (experimental) The SQS queue to be used as deadLetterQueue. Check out the [considerations for using a dead-letter queue](https://docs.aws.amazon.com/eventbridge/latest/userguide/rule-dlq.html#dlq-considerations).
     *
     * The events not successfully delivered are automatically retried for a specified period of time,
     * depending on the retry policy of the target.
     * If an event is not delivered before all retry attempts are exhausted, it will be sent to the dead letter queue.
     *
     * @default - no dead-letter queue
     * @experimental
     */
    readonly deadLetterQueue?: sqs.IQueue;
}
/**
 * (experimental) Use a StepFunctions state machine as a target for Amazon EventBridge rules.
 *
 * @experimental
 */
export declare class SfnStateMachine implements events.IRuleTarget {
    readonly machine: sfn.IStateMachine;
    private readonly props;
    private readonly role;
    /**
     * @experimental
     */
    constructor(machine: sfn.IStateMachine, props?: SfnStateMachineProps);
    /**
     * (experimental) Returns a properties that are used in an Rule to trigger this State Machine.
     *
     * @see https://docs.aws.amazon.com/eventbridge/latest/userguide/resource-based-policies-eventbridge.html#sns-permissions
     * @experimental
     */
    bind(_rule: events.IRule, _id?: string): events.RuleTargetConfig;
}
